@@ -180,67 +180,43 @@ Settings::~Settings()
 
 void Settings::GetProgram(QString file)
 {
+    QSettings settings("/usr/share/applications/hildon/" + file + ".desktop", QSettings::IniFormat);
+    settings.beginGroup("Desktop Entry");
+    QString name = settings.value("Name", "no name").toString();
+    QString icon = settings.value("Icon", "no icon").toString();
+    QString domain("maemo-af-desktop");
+    if(settings.contains("X-Text-Domain"))
+        domain = settings.value("X-Text-Domain").toString();
+    name = QString::fromUtf8(dgettext(domain.toLatin1(), name.toLatin1()));
 
-    QString line, texto, dominio, icon, icono, tipo, mostrar;
-    texto=""; dominio=""; icon="", tipo="", mostrar="";
-    QFile data( "/usr/share/applications/hildon/" + file + ".desktop" );
-    if (data.open(QFile::ReadOnly | QFile::Truncate))
-    {
-         QTextStream out(&data);
-         while ( !out.atEnd() )
-         {
-             line = out.readLine();
-             if ( line.indexOf("Name=") == 0 ) if ( texto=="") texto = line;
-             if ( line.indexOf("Icon=") == 0 ) icon = line;
-             if ( line.indexOf("Type=") == 0 ) tipo = line;
-             if ( line.indexOf("NoDisplay=") == 0 ) mostrar = line;
-             if ( line.indexOf("X-Text-Domain=") == 0 ) dominio = line;
-         }
-     }
-    data.close();
-    texto.replace("Name=",""); texto = texto.trimmed();
-    icon.replace("Icon=",""); icon = icon.trimmed();
-    tipo.replace("Type=",""); tipo = tipo.trimmed();
-    mostrar.replace("NoDisplay=",""); mostrar = mostrar.trimmed();
-    dominio.replace("X-Text-Domain=",""); dominio = dominio.trimmed();
 
-    QString tema = "";
-    QFile data2( "/etc/hildon/theme/index.theme" );
-    if (data2.open(QFile::ReadOnly | QFile::Truncate))
-    {
-         QTextStream out(&data2);
-         while ( !out.atEnd() )
-         {
-             line = out.readLine();
-             if ( line.indexOf("IconTheme=") == 0 ) if ( tema=="") tema = line;
-         }
-     }
-    data2.close();
-    tema.replace("IconTheme=","");
+    QSettings settings2("/etc/hildon/theme/index.theme", QSettings::IniFormat);
+    settings2.beginGroup("X-Hildon-Metatheme");
+    QString tema = settings2.value("IconTheme", "hicolor").toString();
     tema = tema.trimmed();
 
-
-    if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png";
-    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png";
-    else if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png").exists() )
+    QString icono;
+    if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png";
 
-    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png";
-    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/apps/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/hicolor/48x48/apps/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/64x64/apps/" + icon + ".png").exists() )
         icono = "/usr/share/icons/hicolor/64x64/apps/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/apps/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/hicolor/48x48/apps/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/scalable/apps/" + icon + ".png").exists() )
@@ -252,15 +228,7 @@ void Settings::GetProgram(QString file)
         icono = "/opt/maemo/usr/share/pixmaps/" + icon + ".png";
     else icono = "/usr/share/icons/hicolor/64x64/hildon/tasklaunch_default_application.png";
 
-    if ( dominio == "" ) dominio="maemo-af-desktop";
-    QByteArray ba1 = texto.toLatin1();
-    const char *str1 = ba1.data();
-    QByteArray ba2 = dominio.toLatin1();
-    const char *str2 = ba2.data();
-
-    texto = dgettext(str2,str1);
-
-    tem1 = texto;
+    tem1 = name;
     tem2 = icono;
 
 
