@@ -79,48 +79,79 @@ Widget::Widget(QWidget *parent)
 
 void Widget::orientationChanged(const QString &orientation)
 {
+    autorotate = loadSetting("Autorotation","NO").toString();
+    if ( autorotate == "NO" )
+        return;
+
     if (orientation == QLatin1String(MCE_ORIENTATION_PORTRAIT) || orientation == QLatin1String(MCE_ORIENTATION_PORTRAIT_INVERTED))
-    {
         windowmode = "Portrait";
-    }
     else
-    {
         windowmode = "Landscape";
-    }
     loadProgs();
+
 }
 
 
 void Widget::mouseReleaseEvent(QMouseEvent *event)
 {
-    qDebug() << "Mouse release event" << event->x() << event->y();
+    //qDebug() << "Mouse release event" << event->x() << event->y();
 
     programs = loadSetting("Programs").toStringList();
+    vertical = loadSetting("Vertical","NO").toString();
     QString proc;
 
-    int i = event->x();
-    if ( i > 20 && i < 75  && programs.count() > 0 )
-        proc = programs.at(0);
-    else if ( i > 95 && i < 150 && programs.count() > 1 )
-        proc = programs.at(1);
-    else if ( i > 170 && i < 225 && programs.count() > 2 )
-        proc = programs.at(2);
-    else if ( i > 245 && i < 300 && programs.count() > 3 )
-        proc = programs.at(3);
-    else if ( i > 320 && i < 375 && programs.count() > 4 )
-        proc = programs.at(4);
-    else if ( i > 395 && i < 450 && programs.count() > 5 )
-        proc = programs.at(5);
-    else if ( i > 470 && i < 525 && programs.count() > 6 )
-        proc = programs.at(6);
-    else if ( i > 545 && i < 600 && programs.count() > 7 )
-        proc = programs.at(7);
-    else if ( i > 620 && i < 675 && programs.count() > 8 )
-        proc = programs.at(8);
-    else if ( i > 695 && i < 750 && programs.count() > 9 )
-        proc = programs.at(9);
+    if ( vertical == "NO" )
+    {
+        int i = event->x();
+        if ( i > 20 && i < 75  && programs.count() > 0 )
+            proc = programs.at(0);
+        else if ( i > 95 && i < 150 && programs.count() > 1 )
+            proc = programs.at(1);
+        else if ( i > 170 && i < 225 && programs.count() > 2 )
+            proc = programs.at(2);
+        else if ( i > 245 && i < 300 && programs.count() > 3 )
+            proc = programs.at(3);
+        else if ( i > 320 && i < 375 && programs.count() > 4 )
+            proc = programs.at(4);
+        else if ( i > 395 && i < 450 && programs.count() > 5 )
+            proc = programs.at(5);
+        else if ( i > 470 && i < 525 && programs.count() > 6 )
+            proc = programs.at(6);
+        else if ( i > 545 && i < 600 && programs.count() > 7 )
+            proc = programs.at(7);
+        else if ( i > 620 && i < 675 && programs.count() > 8 )
+            proc = programs.at(8);
+        else if ( i > 695 && i < 750 && programs.count() > 9 )
+            proc = programs.at(9);
+        else
+             return;
+    }
     else
-         return;
+    {
+        int i = event->y();
+        if ( i > 20 && i < 75  && programs.count() > 0 )
+            proc = programs.at(0);
+        else if ( i > 95 && i < 150 && programs.count() > 1 )
+            proc = programs.at(1);
+        else if ( i > 170 && i < 225 && programs.count() > 2 )
+            proc = programs.at(2);
+        else if ( i > 245 && i < 300 && programs.count() > 3 )
+            proc = programs.at(3);
+        else if ( i > 320 && i < 375 && programs.count() > 4 )
+            proc = programs.at(4);
+        else if ( i > 395 && i < 450 && programs.count() > 5 )
+            proc = programs.at(5);
+        else if ( i > 470 && i < 525 && programs.count() > 6 )
+            proc = programs.at(6);
+        else if ( i > 545 && i < 600 && programs.count() > 7 )
+            proc = programs.at(7);
+        else if ( i > 620 && i < 675 && programs.count() > 8 )
+            proc = programs.at(8);
+        else if ( i > 695 && i < 750 && programs.count() > 9 )
+            proc = programs.at(9);
+        else
+             return;
+    }
 
     QString proceso = "/usr/bin/dbus-send --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:" + proc;
     Proc->start(proceso, QProcess::ReadOnly);
@@ -151,67 +182,42 @@ void Widget::loadProgs()
 
 void Widget::GetProg(QString file)
 {
+    QSettings settings("/usr/share/applications/hildon/" + file + ".desktop", QSettings::IniFormat);
+    settings.beginGroup("Desktop Entry");
+    QString name = settings.value("Name", "no name").toString();
+    QString icon = settings.value("Icon", "no icon").toString();
+    QString domain("maemo-af-desktop");
+    if(settings.contains("X-Text-Domain"))
+        domain = settings.value("X-Text-Domain").toString();
+    name = QString::fromUtf8(dgettext(domain.toLatin1(), name.toLatin1()));
 
-    QString line, texto, dominio, icon, icono, tipo, mostrar;
-    texto=""; dominio=""; icon="", tipo="", mostrar="";
-    QFile data( "/usr/share/applications/hildon/" + file + ".desktop" );
-    if (data.open(QFile::ReadOnly | QFile::Truncate))
-    {
-         QTextStream out(&data);
-         while ( !out.atEnd() )
-         {
-             line = out.readLine();
-             if ( line.indexOf("Name=") == 0 ) if ( texto=="") texto = line;
-             if ( line.indexOf("Icon=") == 0 ) icon = line;
-             if ( line.indexOf("Type=") == 0 ) tipo = line;
-             if ( line.indexOf("NoDisplay=") == 0 ) mostrar = line;
-             if ( line.indexOf("X-Text-Domain=") == 0 ) dominio = line;
-         }
-     }
-    data.close();
-    texto.replace("Name=",""); texto = texto.trimmed();
-    icon.replace("Icon=",""); icon = icon.trimmed();
-    tipo.replace("Type=",""); tipo = tipo.trimmed();
-    mostrar.replace("NoDisplay=",""); mostrar = mostrar.trimmed();
-    dominio.replace("X-Text-Domain=",""); dominio = dominio.trimmed();
-
-    QString tema = "";
-    QFile data2( "/etc/hildon/theme/index.theme" );
-    if (data2.open(QFile::ReadOnly | QFile::Truncate))
-    {
-         QTextStream out(&data2);
-         while ( !out.atEnd() )
-         {
-             line = out.readLine();
-             if ( line.indexOf("IconTheme=") == 0 ) if ( tema=="") tema = line;
-         }
-     }
-    data2.close();
-    tema.replace("IconTheme=","");
+    QSettings settings2("/etc/hildon/theme/index.theme", QSettings::IniFormat);
+    settings2.beginGroup("X-Hildon-Metatheme");
+    QString tema = settings2.value("IconTheme", "hicolor").toString();
     tema = tema.trimmed();
 
-
-    if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png";
-    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png";
-    else if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png").exists() )
+    QString icono;
+    if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png").exists() )
         icono = "/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png";
 
-    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png";
-    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/apps/" + icon + ".png").exists() )
-        icono = "/usr/share/icons/hicolor/48x48/apps/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/64x64/apps/" + icon + ".png").exists() )
         icono = "/usr/share/icons/hicolor/64x64/apps/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png";
+    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/apps/" + icon + ".png").exists() )
+        icono = "/usr/share/icons/hicolor/48x48/apps/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png").exists() )
         icono = "/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png";
     else if ( QFileInfo("/usr/share/icons/hicolor/scalable/apps/" + icon + ".png").exists() )
@@ -223,15 +229,7 @@ void Widget::GetProg(QString file)
         icono = "/opt/maemo/usr/share/pixmaps/" + icon + ".png";
     else icono = "/usr/share/icons/hicolor/64x64/hildon/tasklaunch_default_application.png";
 
-    if ( dominio == "" ) dominio = "maemo-af-desktop";
-    QByteArray ba1 = texto.toLatin1();
-    const char *str1 = ba1.data();
-    QByteArray ba2 = dominio.toLatin1();
-    const char *str2 = ba2.data();
-
-    texto = dgettext(str2,str1);
-
-    temp1 = file;
+    temp1 = name;
     temp2 = icono;
 
 
